pygerber.renderer.aperture package
==================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   pygerber.renderer.aperture.aperture
   pygerber.renderer.aperture.circular
   pygerber.renderer.aperture.custom
   pygerber.renderer.aperture.polygon
   pygerber.renderer.aperture.rectangular
   pygerber.renderer.aperture.region

Module contents
---------------

.. automodule:: pygerber.renderer.aperture
   :members:
   :undoc-members:
   :show-inheritance:
